package com.qiyuesuo.sdk.api;

import java.io.OutputStream;

import com.qiyuesuo.sdk.auth.AuthFileType;
import com.qiyuesuo.sdk.auth.AuthUrlResponse;
import com.qiyuesuo.sdk.auth.CompanyAuth;
import com.qiyuesuo.sdk.auth.CompanyAuthDetailResponse;
import com.qiyuesuo.sdk.exception.BaseSdkException;

/**
 * 企业认证接口
 */
public interface AuthService {
	
	/**
	 * 申请基本认证
	 * @param companyAuth
	 * @return 认证id
	 */
	Long applyBasic(CompanyAuth companyAuth) throws BaseSdkException;
	
	/**
	 * 申请加强认证；申请加强认证需要认证企业向契约锁账户打款（10元以下）来认证
	 * @param companyAuth
	 * @return 认证id
	 */
	Long applyFull(CompanyAuth companyAuth) throws BaseSdkException;
	
	/**
	 * 查询认证状态
	 * @param id 认证id
	 * @return
	 */
	CompanyAuthDetailResponse detail(Long id) throws BaseSdkException;
	
	/**
	 * 查询认证状态
	 * @param name 公司名称
	 * @return
	 */
	CompanyAuthDetailResponse detail(String name) throws BaseSdkException;
	
	/**
	 * 下载认证文件（营业执照、授权委托书）
	 * @param id
	 * @param type
	 * @param outputStream
	 */
	void downloadFile(Long id, AuthFileType type, OutputStream outputStream);
	
	/**
	 * 初级认证页面地址
	 * @param name 企业名称
	 * @param registerNo 工商注册号
	 * @param successUrl 认证完成后跳转地址
	 * @return
	 */
	AuthUrlResponse basicUrl(String name, String registerNo, String successUrl);
	
	/**
	 * 加强认证页面地址
	 * @param name 企业名称
	 * @param registerNo 工商注册号
	 * @param successUrl 认证完成后跳转地址
	 * @return
	 */
	AuthUrlResponse fullUrl(String name, String registerNo, String successUrl);
	
	/**
	 * 认证查看地址
	 * @param name 企业名称
	 * @return
	 */
	AuthUrlResponse viewUrl(String name);
	
}
