package com.qiyuesuo.sdk.api;

import java.io.OutputStream;
import java.util.List;

import com.qiyuesuo.sdk.exception.BaseSdkException;
import com.qiyuesuo.sdk.standard.AddDocumentRequest;
import com.qiyuesuo.sdk.standard.Category;
import com.qiyuesuo.sdk.standard.CreateContractRequest;
import com.qiyuesuo.sdk.standard.CreateContractResponse;
import com.qiyuesuo.sdk.standard.SendRequest;
import com.qiyuesuo.sdk.standard.SignByLegalPersonRequest;
import com.qiyuesuo.sdk.standard.SignRequest;
import com.qiyuesuo.sdk.standard.StandardContract;

/**
 * 标准签
 */
public interface StandardSignService {

	/**
	 * 下载合同清单，包括合同文档和合同详情的pdf文件
	 * @param contractId				合同ID
	 * @param outputZip					输出合同压缩包数据流（zip）
	 * @throws BaseSdkException         SDK内部错误
	 */
	void download(Long contractId, OutputStream outputZip) throws BaseSdkException;
	
	/**
	 * 下载合同压缩包；包括合同文档和合同详情的pdf文件
	 * @param documentId				合同文档ID
	 * @param outputPdf					合同文档输出流（pdf）
	 * @throws BaseSdkException			SDK内部错误
	 */
	void downloadDoc(Long documentId,OutputStream outputPdf) throws BaseSdkException;

	/**
	 * 查询合同详情
	 * @param contractId				合同ID
	 * @return							合同详情
	 * @throws BaseSdkException         SDK内部错误
	 */
	StandardContract detail(Long contractId) throws BaseSdkException;
	
	/**
	 * 获取签署合同页面的链接
	 * @param documentId				合同文档ID；required
	 * @param successUrl				签署成功跳转链接；optional
	 * @return 签署合同页面的链接
	 * @throws BaseSdkException         SDK内部错误
	 */
//	String signUrl(Long documentId, String successUrl) throws BaseSdkException;
	
	/**
	 * 获取查看合同页面的链接
	 * @param contractId				合同文档ID
	 * @return 浏览合同页面链接
	 * @throws BaseSdkException         SDK内部错误
	 */
	String viewUrl(Long contractId) throws BaseSdkException;
	
	/**
	 * 查询合同分类
	 * @return
	 * @throws BaseSdkException
	 */
	List<Category> queryCategory() throws BaseSdkException;
	
	/**
	 * 初始化合同
	 * @param request
	 * @return
	 */
	CreateContractResponse create(CreateContractRequest request);
	
	/**
	 * 添加合同文件
	 * @param request
	 * @return
	 */
	Long addDocument(AddDocumentRequest request);
	
	/**
	 * 发起合同
	 * @param request
	 */
	void send(SendRequest request);

	/**
	 * 签署合同
	 * @param request					请求参数
	 * @throws BaseSdkException         SDK内部错误
	 * @return
	 */
	void sign(SignRequest request) throws BaseSdkException;
	
	/**
	 * 签署法人章
	 * @param request					请求参数
	 * @throws BaseSdkException         SDK内部错误
	 * @return
	 */
	void signByLegalPerson(SignByLegalPersonRequest request) throws BaseSdkException;
	
	
	/**
	 * 发送通知
	 * @param contractId				合同ID
	 */
	void sendNotice(Long contractId);
	
	/**
	 * 签署链接
	 * @return
	 */
	String shortUrl(Long contractId);
	
	/**
	 * 撤回合同
	 * @param contractId 合同ID，必传
	 * @param comments 撤回原因
	 */
	void recall(Long contractId, String comments);
	
}
