package com.qiyuesuo.sdk.sign;

import java.util.ArrayList;
import java.util.List;

import com.qiyuesuo.sdk.exception.BaseSdkException;
import com.qiyuesuo.sdk.http.HttpParamers;
import com.qiyuesuo.sdk.http.HttpRequest;
import com.qiyuesuo.sdk.signer.Signer;
import com.qiyuesuo.sdk.utils.JsonUtils;
import com.qiyuesuo.tools.json.JSONObject;

/**
 * 远程签获取签署链接接口的请求参数
 */
public class SignUrlRequest implements HttpRequest {
	private Long documentId;								// 合同ID
	private SignType signType;                     // required,合同接收人
	private Signer signer;                              // 合同分类ID  如果为空选择默认合同分类
	private String sealData;
	private List<Stamper> stampers;
	protected String successUrl;    // 签署顺序  默认顺序签署
	private String callbackUrl;
	
	@Override
	public HttpParamers getHttpParamers() {
		if(documentId==null){
			throw new BaseSdkException("documentId不能为空");
		}
		if(signType == null) {
			throw new BaseSdkException("signType不能为空");
		}
		if(signer==null){
			throw new BaseSdkException("signer不能为空");
		}
		if(successUrl == null) {
			throw new BaseSdkException("successUrl不能为空");
		}
		
		HttpParamers paramers = HttpParamers.httpPostParamers();
		paramers.addParam("documentId", String.valueOf(documentId));
		paramers.addParam("operation", signType.name());
		paramers.addParam("signer", JsonUtils.toJson(signer));
		paramers.addParam("successUrl", successUrl);
		if(stampers != null && !stampers.isEmpty()) {
			paramers.addParam("locationMulti", JSONObject.valueToString(stampers));
			paramers.addParam("multiSign", "true");
		}
		if(sealData != null) {
			paramers.addParam("sealImageBase64", sealData);
		}
		if(callbackUrl != null){
			paramers.addParam("signCallBackUrl", callbackUrl);
		}
		return paramers;
	}

	public void addStamper(Stamper stamper) {
		if(stampers == null) {
			stampers = new ArrayList<Stamper>();
		}
		stampers.add(stamper);
	}
	
	public Long getDocumentId() {
		return documentId;
	}

	public void setDocumentId(Long documentId) {
		this.documentId = documentId;
	}

	public SignType getSignType() {
		return signType;
	}

	public void setSignType(SignType signType) {
		this.signType = signType;
	}

	public Signer getSigner() {
		return signer;
	}

	public void setSigner(Signer signer) {
		this.signer = signer;
	}

	public String getSealData() {
		return sealData;
	}

	public void setSealData(String sealData) {
		this.sealData = sealData;
	}

	public List<Stamper> getStampers() {
		return stampers;
	}

	public void setStampers(List<Stamper> stampers) {
		this.stampers = stampers;
	}

	public String getSuccessUrl() {
		return successUrl;
	}

	public void setSuccessUrl(String successUrl) {
		this.successUrl = successUrl;
	}

	public String getCallbackUrl() {
		return callbackUrl;
	}

	public void setCallbackUrl(String callbackUrl) {
		this.callbackUrl = callbackUrl;
	}
	
}
