package com.qiyuesuo.sdk.sign;

import java.io.Serializable;

/**
 * 签名位置参数
 */
public class Stamper implements Serializable {

	private static final long serialVersionUID = 1L;

	private int page; // 签名所在页码
	private String keyword; // 关键字
	private float offsetX; // 签名横坐标,当关键字字段不为空时表示关键字X偏移量
	private float offsetY; // 签名纵坐标,当关键字字段不为空时表示关键字Y偏移量
	private int keywordIndex = 1; // 签第几个关键字；1 为第个，0 为所有，-1 为倒数第一个
	private Float heightPercent; // 印章高度占比
	
	/**
	 * 骑缝章位置，此字段在远程签时用到
	 */
	private Double acrossPagePosition;
	
	/**
	 * 所有关键字位置都签名，只支持本地签
	 */
	public static final int KEYWORD_INDEX_ALL = 0;
	/**
	 * 最后一个关键字签名，支持本地签和远程签
	 */
	public static final int KEYWORD_INDEX_LAST = -1;
	/**
	 * 第一个关键字签名，支持本地签和远程签
	 */
	public static final int KEYWORD_INDEX_FIRST = 1;

	public Stamper() {}
	
	/**
	 * 关键字确定签字坐标位置，无偏移量
	 * @param keyword 关键字
	 */
	public Stamper(String keyword) {
		super();
		this.keyword = keyword;
	}
	
	/**
	 * 关键字确定签字坐标位置，制定偏移量
	 * @param keyword 关键字
	 * @param offsetX X偏移量
	 * @param offsetY Y偏移量
	 */
	public Stamper(String keyword, float offsetX, float offsetY) {
		super();
		this.keyword = keyword;
		this.offsetX = offsetX;
		this.offsetY = offsetY;
	}
	
	/**
	 * 根据页码确定签名位置
	 * @param page 页码
	 * @param offsetX X轴坐标
	 * @param offsetY Y轴坐标
	 */
	public Stamper(int page, float offsetX, float offsetY) {
		super();
		this.page = page;
		this.offsetX = offsetX;
		this.offsetY = offsetY;
	}
	
	public int getPage() {
		return page;
	}
	public void setPage(int page) {
		this.page = page;
	}
	public String getKeyword() {
		return keyword;
	}
	public void setKeyword(String keyword) {
		this.keyword = keyword;
	}
	public float getOffsetX() {
		return offsetX;
	}
	public void setOffsetX(float offsetX) {
		this.offsetX = offsetX;
	}
	public float getOffsetY() {
		return offsetY;
	}
	public void setOffsetY(float offsetY) {
		this.offsetY = offsetY;
	}
	public int getKeywordIndex() {
		return keywordIndex;
	}
	public void setKeywordIndex(int keywordIndex) {
		this.keywordIndex = keywordIndex;
	}
	public Double getAcrossPagePosition() {
		return acrossPagePosition;
	}
	public void setAcrossPagePosition(Double acrossPagePosition) {
		this.acrossPagePosition = acrossPagePosition;
	}
	public Float getHeightPercent() {
		return heightPercent;
	}
	public void setHeightPercent(Float heightPercent) {
		this.heightPercent = heightPercent;
	}

}
