package com.qiyuesuo.sdk.signer;

import com.qiyuesuo.sdk.utils.StringUtils;

/**
 * 公司签署者对象，用于颁发证书。满足以下两个条件中一个即可
 * 1、id,name不为空
 * 2、name不为空，（telephone, email, registerNo）三者至少要有一项不为空
 */
public class Company implements Signer {
	private static final long serialVersionUID = 1L;
	
	private Long id; // 公司id
	private String name; // 公司名称
	private String registerNo; // 工商注册号/社会统一代码
	private String address; // 地址
	private String email; // 邮箱
	private String telephone; // 电话

	public Company() {}
	
	public Company(Long id, String name) {
		super();
		this.id = id;
		this.name = name;
	}

	public Company(String name) {
		super();
		this.name = name;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	@Override
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getRegisterNo() {
		return registerNo;
	}

	public void setRegisterNo(String registerNo) {
		this.registerNo = registerNo;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	@Override
	public boolean valid() {
		if (StringUtils.isBlank(name)) {
			return false;
		}
		if(id == null) {
			if (StringUtils.isBlank(registerNo)) {
				return false;
			}
		}
		return true;
	}

	@Override
	public SignerType getType() {
		return SignerType.COMPANY;
	}

	public String getTelephone() {
		return telephone;
	}

	public void setTelephone(String telephone) {
		this.telephone = telephone;
	}

	public String getMobile() {
		return telephone;
	}

}
