package com.qiyuesuo.sdk.signer;

import com.qiyuesuo.sdk.utils.StringUtils;

/**
 * 个人签署者对象，用于颁发证书，name不能为空，（mobile, email, idcard）三者至少要有一项不为空
 */
public class Person implements Signer {
	private static final long serialVersionUID = 1L;

	private String name; // 姓名
	private String idcard; // 证件编号
	private PaperType paperType; // 证件类型
	private Gender gender; // 性别
	private String mobile; // 手机号
	private String email; // 邮箱

	public Person() {}

	public Person(String name) {
		super();
		this.name = name;
	}
	
	public Person(String name,String idcard) {
		super();
		this.name = name;
		this.idcard =idcard;
		this.paperType =PaperType.IDCARD;
	}

	@Override
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getIdcard() {
		return idcard;
	}

	public void setIdcard(String idcard) {
		this.idcard = idcard;
	}

	public PaperType getPaperType() {
		return paperType;
	}

	public void setPaperType(PaperType paperType) {
		this.paperType = paperType;
	}

	public void setPaper(PaperType paperType, String idcard) {
		this.paperType = paperType;
		this.idcard = idcard;
	}

	public Gender getGender() {
		return gender;
	}

	public void setGender(Gender gender) {
		this.gender = gender;
	}

	public String getMobile() {
		return mobile;
	}

	public void setMobile(String mobile) {
		this.mobile = mobile;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	/**
	 * name不能为空</br>
	 * mobile, email, idcard三者至少要有一项不为空
	 * @return
	 */
	@Override
	public boolean valid() {
		if (StringUtils.isBlank(name)) {
			return false;
		}
		if (StringUtils.isAllBlank(mobile, email, idcard)) {
			return false;
		}
		return true;
	}

	@Override
	public SignerType getType() {
		return SignerType.PERSONAL;
	}

}
