package com.qiyuesuo.sdk.standard;

import java.util.Map;

import com.qiyuesuo.sdk.exception.BaseSdkException;
import com.qiyuesuo.sdk.http.HttpParamers;
import com.qiyuesuo.sdk.impl.StandardSignServiceImpl;
import com.qiyuesuo.sdk.utils.JsonUtils;
import com.qiyuesuo.sdk.utils.StringUtils;

/**
 * 标准签添加合同文件请求参数：用合同模板添加合同文件
 */
public class AddDocumentByTemplateRequest extends AddDocumentRequest {

	private Long templateId;
	private Map<String, String> templateParams;

	@Override
	public String getRequestUrl() {
		return StandardSignServiceImpl.ADDDOCUMENT_BYTEMPLATE;
	}

	@Override
	public HttpParamers getHttpParamers() {
		if(contractId == null) {
			throw new BaseSdkException("contractId不能为空");
		}
		if(StringUtils.isBlank(title)) {
			throw new BaseSdkException("title不能为空");
		}
		if(templateId == null) {
			throw new BaseSdkException("templateId不能为空");
		}
		HttpParamers paramers = HttpParamers.httpPostParamers();
		paramers.addParam("contractId", String.valueOf(contractId));
		paramers.addParam("title", title);
		paramers.addParam("templateId", String.valueOf(templateId));
		if(templateParams != null && !templateParams.isEmpty()) {
			paramers.addParam("templateParams", JsonUtils.toJson(templateParams));
		}
		return paramers;
	}
	
	public Long getTemplateId() {
		return templateId;
	}
	public void setTemplateId(Long templateId) {
		this.templateId = templateId;
	}
	public Map<String, String> getTemplateParams() {
		return templateParams;
	}
	public void setTemplateParams(Map<String, String> templateParams) {
		this.templateParams = templateParams;
	}

}
