package com.qiyuesuo.sdk.standard;

import java.util.List;

import com.qiyuesuo.sdk.exception.BaseSdkException;
import com.qiyuesuo.sdk.http.HttpParamers;
import com.qiyuesuo.sdk.http.HttpRequest;
import com.qiyuesuo.sdk.utils.StringUtils;
import com.qiyuesuo.tools.json.JSONObject;

/**
 * 标准签发起合同请求参数
 */
public class SendRequest implements HttpRequest {

	private String sn;                                      // 合同编号
	private Long contractId;								// 合同ID
	protected List<Receiver> receivers;                     // required,合同接收人
	protected Long categoryId;                              // 合同分类ID  如果为空选择默认合同分类
	protected ReceiveType receiveType = ReceiveType.SEQ;    // 签署顺序  默认顺序签署
	
	@Override
	public HttpParamers getHttpParamers() {
		if(contractId == null) {
			throw new BaseSdkException("contractId不能为空");
		}
		if(receivers == null || receivers.isEmpty()) {
			throw new BaseSdkException("receivers不能为空");
		}
		HttpParamers paramers = HttpParamers.httpPostParamers();
		paramers.addParam("contractId", String.valueOf(contractId));
		paramers.addParam("receivers", JSONObject.valueToString(receivers));
		paramers.addParam("receiveType", String.valueOf(receiveType));
		if(categoryId != null) {
			paramers.addParam("categoryId", String.valueOf(categoryId));
		}
		if(StringUtils.isNotBlank(sn)) {
			paramers.addParam("sn", sn);
		}
		
		return paramers;
	}
	
	public Long getContractId() {
		return contractId;
	}
	public void setContractId(Long contractId) {
		this.contractId = contractId;
	}
	public List<Receiver> getReceivers() {
		return receivers;
	}
	public void setReceivers(List<Receiver> receivers) {
		this.receivers = receivers;
	}
	public Long getCategoryId() {
		return categoryId;
	}
	public void setCategoryId(Long categoryId) {
		this.categoryId = categoryId;
	}
	public ReceiveType getReceiveType() {
		return receiveType;
	}
	public void setReceiveType(ReceiveType receiveType) {
		this.receiveType = receiveType;
	}

	public String getSn() {
		return sn;
	}

	public void setSn(String sn) {
		this.sn = sn;
	}
	
}
